#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   digest
version:                0.0.2.1
visibility:             public
id:                     digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
key:                    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
license:                BSD-2-Clause
copyright:              (c) 2009 Eugene Kirpichov
maintainer:             Eugene Kirpichov <ekirpichov@gmail.com>
author:                 Eugene Kirpichov <ekirpichov@gmail.com>
stability:              provisional
synopsis:               CRC32 and Adler32 hashes for bytestrings
description:
    This package provides efficient hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:               Cryptography
abi:                    5f3c9fbcc65aa7c1bc6b9ceb21239e3f
exposed:                True
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32 Data.Digest.CRC32C

import-dirs:            /usr/lib/ghc-9.6.6/site-local/digest-0.0.2.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/digest-0.0.2.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/digest-0.0.2.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-digest
hs-libraries:           HSdigest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
extra-libraries:        z
extra-libraries-static: z
include-dirs:           /usr/include
includes:               zlib.h
depends:                base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:           /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

